@@ -25,9 +25,10 @@ class RackspaceCreate(Command):
         super(RackspaceCreate, self).__init__(rackspace_api)
         self.chef_deploy = chef_deployer
 
-    def execute(self, node_name, flavor, image, public_key_file, environment=None, hostname=None, **kwargs):
+    def execute(self, node_name, flavor, image, public_key_file, environment=None, hostname=None, networks=None, **kwargs):
         host = self.rackspace_api.create_node(node_name=node_name, flavor=flavor,
                                               image=image, public_key_file=public_key_file,
+                                              networks=networks,
                                               progress=sys.stderr)
         if environment:
             host.environment = environment
@@ -65,3 +66,18 @@ class RackspaceListFlavors(Command):
         flavors = self.rackspace_api.list_flavors()
         for flavor in flavors:
             progress.write('{0}{1}\n'.format(flavor['id'].ljust(10), flavor['name']))
+
+class RackspaceListNetworks(Command):
+
+    name = "list-networks"
+    description = "List available networks for a Cloud Servers endpoint"
+    requires_api = True
+
+    def execute(self, progress=sys.stderr, **kwargs):
+        networks = self.rackspace_api.list_networks()
+
+        for network in networks:
+            cidr = network['cidr'] or '--'
+            progress.write('{0}{1}{2}\n'.format(network['id'].ljust(41),
+                                                cidr.ljust(20),
+                                                network['name']))
